@@ -3,6 +3,7 @@ import logging
 import json
 from typing import Dict, List
 import urllib.request
+import re
 
 import toml
 import yaml
@@ -107,6 +108,9 @@ class Config:
         except KeyError:
             return default
 
+        item = self.replace_variables(item)
+
+
         return item
 
     def __setitem__(self, key: str, value: any):
@@ -236,4 +240,37 @@ class Config:
                 ret.append(self._make_lowercase(item))
             return ret
         else:
-            return obj
\ No newline at end of file
+            return obj
+
+    def replace_variables(self, obj):
+        if isinstance(obj, dict):
+            ret = {}
+            for k,v in obj.items():
+                ret[k] = self.replace_variables(v)
+            return ret
+        elif isinstance(obj, str):
+            for m in re.finditer('\$\{(?P<key1>[^\}]+):(?P<fallback>[^}]+)\}|\$\{(?P<key2>[^\}]+)\}', obj):
+                match = m.group(0)
+                key = m.group('key1') if m.group('key1') else m.group('key2')
+                fallback = m.group('fallback')
+                
+                replacement = self.get(key)
+                if replacement == None:
+                    if fallback:
+                        replacement = fallback
+                    else:
+                        replacement = ''
+                obj = obj.replace(match, replacement, 1)
+
+
+            return obj
+        elif hasattr(obj,'__iter__'):
+            ret = []
+            for item in obj:
+                ret.append(self.replace_variables(item))
+            return ret
+        else:
+            return obj
+
+
+                    
\ No newline at end of file
